@@ -1,3 +1,4 @@
+if (requireNamespace("rpart")) {
 d = getTaskData(yeast.task)
 # drop some labels so example runs faster
 d = d[seq(1, nrow(d), by = 20), c(1:2, 15:17)]
@@ -12,3 +13,4 @@ performance(pred, measure = list(multilabel.hamloss, multilabel.subset01, multil
 # the next call basically has the same structure for any multilabel meta wrapper
 getMultilabelBinaryPerformances(pred, measures = list(mmce, auc))
 # above works also with predictions from resample!
+}
