@@ -1,4 +1,3 @@
-context("orderBMRLevels")
 
 test_that("RankMatrix", {
   lrns = list(makeLearner("classif.nnet"), makeLearner("classif.rpart"))
@@ -15,15 +14,15 @@ test_that("RankMatrix", {
   # Test ordering Lrns
   # Test Class
   r1 = orderBMRLrns(res, order.lrns = lrn.id1)
-  expect_is(r1, "data.frame")
+  expect_s3_class(r1, "data.frame")
   r2 = orderBMRLrns(res, order.lrns = lrn.id2)
-  expect_is(r2, "data.frame")
+  expect_s3_class(r2, "data.frame")
   # Test constant dimensions
   expect_equal(dim(r1), dim(as.data.frame(res)))
   expect_equal(dim(r2), dim(as.data.frame(res)))
 
   # Test ordering Tsks
   r3 = orderBMRTasks(res, order.tsks = tsk.id1)
-  expect_is(r3, "data.frame")
+  expect_s3_class(r3, "data.frame")
   expect_equal(dim(r2), dim(as.data.frame(res)))
 })
